summaryrefslogtreecommitdiff
path: root/MdePkg/Library/BaseLib/X64/Thunk16.S
diff options
context:
space:
mode:
Diffstat (limited to 'MdePkg/Library/BaseLib/X64/Thunk16.S')
-rw-r--r--MdePkg/Library/BaseLib/X64/Thunk16.S6
1 files changed, 3 insertions, 3 deletions
diff --git a/MdePkg/Library/BaseLib/X64/Thunk16.S b/MdePkg/Library/BaseLib/X64/Thunk16.S
index a521aff31..f592a2868 100644
--- a/MdePkg/Library/BaseLib/X64/Thunk16.S
+++ b/MdePkg/Library/BaseLib/X64/Thunk16.S
@@ -146,8 +146,8 @@ L_64Eip: .space 4
L_SavedCs: .space 2
L_64BitCode:
.byte 0x90
- .byte 0x67,0xbc # mov esp, imm32
-L_SavedSp: .space 4 # restore stack
+ .byte 0x48,0xbc # mov rsp, imm64
+L_SavedSp: .space 8 # restore stack
nop
ret
@@ -307,7 +307,7 @@ ASM_PFX(InternalAsmThunk16):
pushq %r8
movl %cs, %r8d
movw %r8w, (L_SavedCs - L_SavedCr4)(%rcx)
- movl %esp, (L_SavedSp - L_SavedCr4)(%rcx)
+ movq %rsp, (L_SavedSp - L_SavedCr4)(%rcx)
.byte 0xff, 0x69 # jmp (_EntryPoint - L_SavedCr4)(%rcx)
.set Ltemp1, _EntryPoint - L_SavedCr4
.byte Ltemp1